**********
DataBroker
**********

Search for data, and retrieve it as SciPy/PyData data structures for
interactive data exploration or in
`a representation suitable for streaming applications <https://blueskyproject.io/event-model>`_ .

If you are here to...

* use the legacy "Version 1" user interace to databroker, see :doc:`v1/index`;
* try the new "Version 2" user interace to databroker, see the :doc:`v2/user/index`;
* configure or administrate data sources using databroker, see
  the :doc:`v2/administrator/index`;
* develop support for new storage formats or understand databroker's internal
  workings, see the :doc:`v2/developer/index`.

.. toctree::
   :maxdepth: 2

   overview
   installation
   v2/index
   v1/index
   whats_new
   DBEP/index

.. toctree::
   :hidden:
   :caption: Bluesky Project

   Homepage <https://blueskyproject.io>
   GitHub <https://github.com/bluesky>

.. toctree::
   :hidden:
   :caption: Getting Help

   Gitter <https://gitter.im/NSLS-II/DAMA>
